@@ -38,7 +38,7 @@ get.ArAr.age <- function(Ar40Ar39,sAr40Ar39,J,sJ,exterr=TRUE){
 
 # x an object of class \code{ArAr} returns a matrix 
 # of 40Ar/39Ar-ages and their uncertainties.
-ArAr.age <- function(x,exterr=TRUE,i=NA,i2i=FALSE,projerr=FALSE,omit4c=NULL){
+ArAr.age <- function(x,exterr=TRUE,i=NULL,i2i=FALSE,projerr=FALSE,omit4c=NULL){
     ns <- length(x)
     if (ns<2) i2i <- FALSE
     out <- matrix(0,ns,2)
@@ -66,7 +66,7 @@ ArAr.age <- function(x,exterr=TRUE,i=NA,i2i=FALSE,projerr=FALSE,omit4c=NULL){
     if (projerr) sDP <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12)
     else sDP <- errorprop1x2(J1,J2,E11,E22,E12)
     out <- get.ArAr.age(DP,sDP,x$J[1],x$J[2],exterr=exterr)
-    if (!is.na(i)) out <- out[i,]
+    if (!is.null(i)) out <- out[i,]
     colnames(out) <- c('t','s[t]')
     out
 }
