@@ -107,6 +107,6 @@ get.SmNd.age <- function(Nd143Sm147,sNd143Sm147,exterr=TRUE){
     get.PD.age(Nd143Sm147,sNd143Sm147,'Sm147',exterr=exterr)
 }
 
-SmNd.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,i2i=TRUE,projerr=FALSE,...){
+SmNd.age <- function(x,exterr=TRUE,i=NULL,sigdig=NA,i2i=TRUE,projerr=FALSE,...){
     PD.age(x,'Sm147',exterr=exterr,i=i,sigdig=sigdig,i2i=i2i,projerr=projerr,...)
 }
